BT

Struct BT 

#[non_exhaustive]
pub struct BT<'a> { /* private fields */ }
Available on crate features unstable only.
BT peripheral singleton

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations



impl BT<'_>

pub fn reset_rpa(&mut self)

Available on bt only.

Reset the Bluetooth Resolvable Private Address (RPA).

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn ble_rtc_clk_init(&mut self)

Available on bt only.

Initialize BLE RTC clocks

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.



impl BT<'_>

pub unsafe fn steal() -> BT<'_>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.

pub unsafe fn clone_unchecked(&self) -> BT<'_>

Unsafely clone this peripheral reference.

Safety

You must ensure that you’re only using one instance of this type at a time.

pub fn reborrow(&mut self) -> BT<'_>

Creates a new peripheral reference with a shorter lifetime.

Use this method if you would like to keep working with the peripheral after you dropped the driver that consumes this.