DMA_CH1

Struct DMA_CH1 

#[non_exhaustive]
pub struct DMA_CH1<'a> { /* private fields */ }
Available on crate features unstable only.
DMA_CH1 peripheral singleton

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations



impl DMA_CH1<'_>

pub unsafe fn steal() -> DMA_CH1<'_>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.

pub unsafe fn clone_unchecked(&self) -> DMA_CH1<'_>

Unsafely clone this peripheral reference.

Safety

You must ensure that you’re only using one instance of this type at a time.

pub fn reborrow(&mut self) -> DMA_CH1<'_>

Creates a new peripheral reference with a shorter lifetime.

Use this method if you would like to keep working with the peripheral after you dropped the driver that consumes this.