Struct DMA_CH2
#[non_exhaustive]pub struct DMA_CH2<'a> { /* private fields */ }Available on crate features
unstable only.Expand description
DMA_CH2 peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
impl DMA_CH2<'_>
impl DMA_CH2<'_>
pub unsafe fn steal() -> DMA_CH2<'_>
pub unsafe fn steal() -> DMA_CH2<'_>
Unsafely create an instance of this peripheral out of thin air.
Safety
You must ensure that you’re only using one instance of this type at a time.
pub unsafe fn clone_unchecked(&self) -> DMA_CH2<'_>
pub unsafe fn clone_unchecked(&self) -> DMA_CH2<'_>
Unsafely clone this peripheral reference.
Safety
You must ensure that you’re only using one instance of this type at a time.