Struct I2C0
#[non_exhaustive]pub struct I2C0<'a> { /* private fields */ }Expand description
I2C0 peripheral singleton
Implementations
impl I2C0<'_>
impl I2C0<'_>
pub unsafe fn steal() -> I2C0<'_>
pub unsafe fn steal() -> I2C0<'_>
Unsafely create an instance of this peripheral out of thin air.
Safety
You must ensure that you’re only using one instance of this type at a time.
pub unsafe fn clone_unchecked(&self) -> I2C0<'_>
pub unsafe fn clone_unchecked(&self) -> I2C0<'_>
Unsafely clone this peripheral reference.
Safety
You must ensure that you’re only using one instance of this type at a time.
pub fn reborrow(&mut self) -> I2C0<'_>
pub fn reborrow(&mut self) -> I2C0<'_>
Creates a new peripheral reference with a shorter lifetime.
Use this method if you would like to keep working with the peripheral after you dropped the driver that consumes this.
pub fn bind_peri_interrupt(&self, handler: IsrCallback)
Available on crate features unstable only.
pub fn bind_peri_interrupt(&self, handler: IsrCallback)
unstable only.Binds an interrupt handler to the corresponding interrupt for this peripheral.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub fn disable_peri_interrupt(&self)
Available on crate features unstable only.
pub fn disable_peri_interrupt(&self)
unstable only.Disables the interrupt handler
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub fn enable_peri_interrupt(&self, priority: Priority)
Available on crate features unstable only.
pub fn enable_peri_interrupt(&self, priority: Priority)
unstable only.Enables the interrupt handler on the given core
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
impl I2C0<'_>
impl I2C0<'_>
pub const PTR: *const <Periph<RegisterBlock, 1610629120> as Deref>::Target = pac::I2C0::PTR
Available on crate features unstable only.
pub const PTR: *const <Periph<RegisterBlock, 1610629120> as Deref>::Target = pac::I2C0::PTR
unstable only.Pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub const fn ptr() -> *const <Periph<RegisterBlock, 1610629120> as Deref>::Target
Available on crate features unstable only.
pub const fn ptr() -> *const <Periph<RegisterBlock, 1610629120> as Deref>::Target
unstable only.Return the pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub const fn regs<'a>() -> &'a <Periph<RegisterBlock, 1610629120> as Deref>::Target
Available on crate features unstable only.
pub const fn regs<'a>() -> &'a <Periph<RegisterBlock, 1610629120> as Deref>::Target
unstable only.Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub fn register_block(
&self,
) -> &<Periph<RegisterBlock, 1610629120> as Deref>::Target
Available on crate features unstable only.
pub fn register_block( &self, ) -> &<Periph<RegisterBlock, 1610629120> as Deref>::Target
unstable only.Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.