Struct LP_CORE
#[non_exhaustive]pub struct LP_CORE<'a> { /* private fields */ }Available on crate features
unstable only.Expand description
LP_CORE peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
impl LP_CORE<'_>
impl LP_CORE<'_>
pub unsafe fn steal() -> LP_CORE<'_>
pub unsafe fn steal() -> LP_CORE<'_>
Unsafely create an instance of this peripheral out of thin air.
Safety
You must ensure that you’re only using one instance of this type at a time.
pub unsafe fn clone_unchecked(&self) -> LP_CORE<'_>
pub unsafe fn clone_unchecked(&self) -> LP_CORE<'_>
Unsafely clone this peripheral reference.
Safety
You must ensure that you’re only using one instance of this type at a time.