Struct LP_I2C_ANA_MST
#[non_exhaustive]pub struct LP_I2C_ANA_MST<'a> { /* private fields */ }unstable only.Expand description
LP_I2C_ANA_MST peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
impl LP_I2C_ANA_MST<'_>
impl LP_I2C_ANA_MST<'_>
pub unsafe fn steal() -> LP_I2C_ANA_MST<'_>
pub unsafe fn steal() -> LP_I2C_ANA_MST<'_>
Unsafely create an instance of this peripheral out of thin air.
Safety
You must ensure that you’re only using one instance of this type at a time.
pub unsafe fn clone_unchecked(&self) -> LP_I2C_ANA_MST<'_>
pub unsafe fn clone_unchecked(&self) -> LP_I2C_ANA_MST<'_>
Unsafely clone this peripheral reference.
Safety
You must ensure that you’re only using one instance of this type at a time.
pub fn reborrow(&mut self) -> LP_I2C_ANA_MST<'_>
pub fn reborrow(&mut self) -> LP_I2C_ANA_MST<'_>
Creates a new peripheral reference with a shorter lifetime.
Use this method if you would like to keep working with the peripheral after you dropped the driver that consumes this.
impl LP_I2C_ANA_MST<'_>
impl LP_I2C_ANA_MST<'_>
pub const PTR: *const <Periph<RegisterBlock, 1611342848> as Deref>::Target = pac::LP_I2C_ANA_MST::PTR
pub const PTR: *const <Periph<RegisterBlock, 1611342848> as Deref>::Target = pac::LP_I2C_ANA_MST::PTR
Pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub const fn ptr() -> *const <Periph<RegisterBlock, 1611342848> as Deref>::Target
pub const fn ptr() -> *const <Periph<RegisterBlock, 1611342848> as Deref>::Target
Return the pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub const fn regs<'a>() -> &'a <Periph<RegisterBlock, 1611342848> as Deref>::Target
pub const fn regs<'a>() -> &'a <Periph<RegisterBlock, 1611342848> as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub fn register_block(
&self,
) -> &<Periph<RegisterBlock, 1611342848> as Deref>::Target
pub fn register_block( &self, ) -> &<Periph<RegisterBlock, 1611342848> as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.