Struct MEM2MEM12
#[non_exhaustive]pub struct MEM2MEM12<'a> { /* private fields */ }Available on crate features
unstable only.Expand description
MEM2MEM12 peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
impl MEM2MEM12<'_>
impl MEM2MEM12<'_>
pub unsafe fn steal() -> MEM2MEM12<'_>
pub unsafe fn steal() -> MEM2MEM12<'_>
Unsafely create an instance of this peripheral out of thin air.
Safety
You must ensure that you’re only using one instance of this type at a time.
pub unsafe fn clone_unchecked(&self) -> MEM2MEM12<'_>
pub unsafe fn clone_unchecked(&self) -> MEM2MEM12<'_>
Unsafely clone this peripheral reference.
Safety
You must ensure that you’re only using one instance of this type at a time.