MEM2MEM4

Struct MEM2MEM4 

#[non_exhaustive]
pub struct MEM2MEM4<'a> { /* private fields */ }
Available on crate features unstable only.
MEM2MEM4 peripheral singleton

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations



impl MEM2MEM4<'_>

pub unsafe fn steal() -> MEM2MEM4<'_>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.

pub unsafe fn clone_unchecked(&self) -> MEM2MEM4<'_>

Unsafely clone this peripheral reference.

Safety

You must ensure that you’re only using one instance of this type at a time.

pub fn reborrow(&mut self) -> MEM2MEM4<'_>

Creates a new peripheral reference with a shorter lifetime.

Use this method if you would like to keep working with the peripheral after you dropped the driver that consumes this.