Struct MEM_MONITOR
#[non_exhaustive]pub struct MEM_MONITOR<'a> { /* private fields */ }unstable only.Expand description
MEM_MONITOR peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
impl MEM_MONITOR<'_>
impl MEM_MONITOR<'_>
pub unsafe fn steal() -> MEM_MONITOR<'_>
pub unsafe fn steal() -> MEM_MONITOR<'_>
Unsafely create an instance of this peripheral out of thin air.
Safety
You must ensure that you’re only using one instance of this type at a time.
pub unsafe fn clone_unchecked(&self) -> MEM_MONITOR<'_>
pub unsafe fn clone_unchecked(&self) -> MEM_MONITOR<'_>
Unsafely clone this peripheral reference.
Safety
You must ensure that you’re only using one instance of this type at a time.
pub fn reborrow(&mut self) -> MEM_MONITOR<'_>
pub fn reborrow(&mut self) -> MEM_MONITOR<'_>
Creates a new peripheral reference with a shorter lifetime.
Use this method if you would like to keep working with the peripheral after you dropped the driver that consumes this.
impl MEM_MONITOR<'_>
impl MEM_MONITOR<'_>
pub const PTR: *const <Periph<RegisterBlock, 1611210752> as Deref>::Target = pac::MEM_MONITOR::PTR
pub const PTR: *const <Periph<RegisterBlock, 1611210752> as Deref>::Target = pac::MEM_MONITOR::PTR
Pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub const fn ptr() -> *const <Periph<RegisterBlock, 1611210752> as Deref>::Target
pub const fn ptr() -> *const <Periph<RegisterBlock, 1611210752> as Deref>::Target
Return the pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub const fn regs<'a>() -> &'a <Periph<RegisterBlock, 1611210752> as Deref>::Target
pub const fn regs<'a>() -> &'a <Periph<RegisterBlock, 1611210752> as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub fn register_block(
&self,
) -> &<Periph<RegisterBlock, 1611210752> as Deref>::Target
pub fn register_block( &self, ) -> &<Periph<RegisterBlock, 1611210752> as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.