PARL_IO

Struct PARL_IO 

#[non_exhaustive]
pub struct PARL_IO<'a> { /* private fields */ }
Available on crate features unstable only.
PARL_IO peripheral singleton

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations



impl PARL_IO<'_>

pub unsafe fn steal() -> PARL_IO<'_>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.

pub unsafe fn clone_unchecked(&self) -> PARL_IO<'_>

Unsafely clone this peripheral reference.

Safety

You must ensure that you’re only using one instance of this type at a time.

pub fn reborrow(&mut self) -> PARL_IO<'_>

Creates a new peripheral reference with a shorter lifetime.

Use this method if you would like to keep working with the peripheral after you dropped the driver that consumes this.

pub fn bind_peri_interrupt(&self, handler: IsrCallback)

Binds an interrupt handler to the corresponding interrupt for this peripheral.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn disable_peri_interrupt(&self)

Disables the interrupt handler

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn enable_peri_interrupt(&self, priority: Priority)

Enables the interrupt handler on the given core

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.



impl PARL_IO<'_>

pub const PTR: *const <Periph<RegisterBlock, 1610698752> as Deref>::Target = pac::PARL_IO::PTR

Pointer to the register block

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub const fn ptr() -> *const <Periph<RegisterBlock, 1610698752> as Deref>::Target

Return the pointer to the register block

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub const fn regs<'a>() -> &'a <Periph<RegisterBlock, 1610698752> as Deref>::Target

Return a reference to the register block

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn register_block( &self, ) -> &<Periph<RegisterBlock, 1610698752> as Deref>::Target

Return a reference to the register block

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.