SW_INTERRUPT

Struct SW_INTERRUPT 

#[non_exhaustive]
pub struct SW_INTERRUPT<'a> { /* private fields */ }
Available on crate features unstable only.
SW_INTERRUPT peripheral singleton

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations



impl SW_INTERRUPT<'_>

pub unsafe fn steal() -> SW_INTERRUPT<'_>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.

pub unsafe fn clone_unchecked(&self) -> SW_INTERRUPT<'_>

Unsafely clone this peripheral reference.

Safety

You must ensure that you’re only using one instance of this type at a time.

pub fn reborrow(&mut self) -> SW_INTERRUPT<'_>

Creates a new peripheral reference with a shorter lifetime.

Use this method if you would like to keep working with the peripheral after you dropped the driver that consumes this.