Struct TSENS
#[non_exhaustive]pub struct TSENS<'a> { /* private fields */ }Available on crate features
unstable only.Expand description
TSENS peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
impl TSENS<'_>
impl TSENS<'_>
pub unsafe fn steal() -> TSENS<'_>
pub unsafe fn steal() -> TSENS<'_>
Unsafely create an instance of this peripheral out of thin air.
Safety
You must ensure that you’re only using one instance of this type at a time.
pub unsafe fn clone_unchecked(&self) -> TSENS<'_>
pub unsafe fn clone_unchecked(&self) -> TSENS<'_>
Unsafely clone this peripheral reference.
Safety
You must ensure that you’re only using one instance of this type at a time.