Struct TWAI1
#[non_exhaustive]pub struct TWAI1<'a> { /* private fields */ }unstable only.Expand description
TWAI1 peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
impl TWAI1<'_>
impl TWAI1<'_>
pub unsafe fn steal() -> TWAI1<'_>
pub unsafe fn steal() -> TWAI1<'_>
Unsafely create an instance of this peripheral out of thin air.
Safety
You must ensure that you’re only using one instance of this type at a time.
pub unsafe fn clone_unchecked(&self) -> TWAI1<'_>
pub unsafe fn clone_unchecked(&self) -> TWAI1<'_>
Unsafely clone this peripheral reference.
Safety
You must ensure that you’re only using one instance of this type at a time.
impl TWAI1<'_>
impl TWAI1<'_>
pub const PTR: *const <Periph<RegisterBlock, 1610665984> as Deref>::Target = pac::TWAI1::PTR
pub const PTR: *const <Periph<RegisterBlock, 1610665984> as Deref>::Target = pac::TWAI1::PTR
Pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub const fn ptr() -> *const <Periph<RegisterBlock, 1610665984> as Deref>::Target
pub const fn ptr() -> *const <Periph<RegisterBlock, 1610665984> as Deref>::Target
Return the pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub const fn regs<'a>() -> &'a <Periph<RegisterBlock, 1610665984> as Deref>::Target
pub const fn regs<'a>() -> &'a <Periph<RegisterBlock, 1610665984> as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub fn register_block(
&self,
) -> &<Periph<RegisterBlock, 1610665984> as Deref>::Target
pub fn register_block( &self, ) -> &<Periph<RegisterBlock, 1610665984> as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.