WIFI

Struct WIFI 

#[non_exhaustive]
pub struct WIFI<'a> { /* private fields */ }
Available on crate features unstable only.
WIFI peripheral singleton

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations



impl WIFI<'_>

pub fn reset_wifi_mac(&mut self)

Available on wifi only.

Reset the Wi-Fi MAC.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.



impl WIFI<'_>

pub unsafe fn steal() -> WIFI<'_>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.

pub unsafe fn clone_unchecked(&self) -> WIFI<'_>

Unsafely clone this peripheral reference.

Safety

You must ensure that you’re only using one instance of this type at a time.

pub fn reborrow(&mut self) -> WIFI<'_>

Creates a new peripheral reference with a shorter lifetime.

Use this method if you would like to keep working with the peripheral after you dropped the driver that consumes this.