Struct HP_SYS
#[non_exhaustive]pub struct HP_SYS<'a> { /* private fields */ }unstable only.Expand description
HP_SYS peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
impl HP_SYS<'_>
impl HP_SYS<'_>
pub unsafe fn steal() -> HP_SYS<'_>
pub unsafe fn steal() -> HP_SYS<'_>
Unsafely create an instance of this peripheral out of thin air.
Safety
You must ensure that you’re only using one instance of this type at a time.
pub unsafe fn clone_unchecked(&self) -> HP_SYS<'_>
pub unsafe fn clone_unchecked(&self) -> HP_SYS<'_>
Unsafely clone this peripheral reference.
Safety
You must ensure that you’re only using one instance of this type at a time.
impl HP_SYS<'_>
impl HP_SYS<'_>
pub const PTR: *const <Periph<RegisterBlock, 1611223040> as Deref>::Target = pac::HP_SYS::PTR
pub const PTR: *const <Periph<RegisterBlock, 1611223040> as Deref>::Target = pac::HP_SYS::PTR
Pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub const fn ptr() -> *const <Periph<RegisterBlock, 1611223040> as Deref>::Target
pub const fn ptr() -> *const <Periph<RegisterBlock, 1611223040> as Deref>::Target
Return the pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub const fn regs<'a>() -> &'a <Periph<RegisterBlock, 1611223040> as Deref>::Target
pub const fn regs<'a>() -> &'a <Periph<RegisterBlock, 1611223040> as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub fn register_block(
&self,
) -> &<Periph<RegisterBlock, 1611223040> as Deref>::Target
pub fn register_block( &self, ) -> &<Periph<RegisterBlock, 1611223040> as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.