Struct IEEE802154
#[non_exhaustive]pub struct IEEE802154<'a> { /* private fields */ }unstable only.Expand description
IEEE802154 peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
impl IEEE802154<'_>
impl IEEE802154<'_>
pub unsafe fn steal() -> IEEE802154<'_>
pub unsafe fn steal() -> IEEE802154<'_>
Unsafely create an instance of this peripheral out of thin air.
Safety
You must ensure that you’re only using one instance of this type at a time.
pub unsafe fn clone_unchecked(&self) -> IEEE802154<'_>
pub unsafe fn clone_unchecked(&self) -> IEEE802154<'_>
Unsafely clone this peripheral reference.
Safety
You must ensure that you’re only using one instance of this type at a time.
pub fn reborrow(&mut self) -> IEEE802154<'_>
pub fn reborrow(&mut self) -> IEEE802154<'_>
Creates a new peripheral reference with a shorter lifetime.
Use this method if you would like to keep working with the peripheral after you dropped the driver that consumes this.
impl IEEE802154<'_>
impl IEEE802154<'_>
pub const PTR: *const <Periph<RegisterBlock, 1611280384> as Deref>::Target = pac::IEEE802154::PTR
pub const PTR: *const <Periph<RegisterBlock, 1611280384> as Deref>::Target = pac::IEEE802154::PTR
Pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub const fn ptr() -> *const <Periph<RegisterBlock, 1611280384> as Deref>::Target
pub const fn ptr() -> *const <Periph<RegisterBlock, 1611280384> as Deref>::Target
Return the pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub const fn regs<'a>() -> &'a <Periph<RegisterBlock, 1611280384> as Deref>::Target
pub const fn regs<'a>() -> &'a <Periph<RegisterBlock, 1611280384> as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub fn register_block(
&self,
) -> &<Periph<RegisterBlock, 1611280384> as Deref>::Target
pub fn register_block( &self, ) -> &<Periph<RegisterBlock, 1611280384> as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.