Struct MODEM_SYSCON
#[non_exhaustive]pub struct MODEM_SYSCON<'a> { /* private fields */ }unstable only.Expand description
MODEM_SYSCON peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
impl MODEM_SYSCON<'_>
impl MODEM_SYSCON<'_>
pub unsafe fn steal() -> MODEM_SYSCON<'_>
pub unsafe fn steal() -> MODEM_SYSCON<'_>
Unsafely create an instance of this peripheral out of thin air.
Safety
You must ensure that you’re only using one instance of this type at a time.
pub unsafe fn clone_unchecked(&self) -> MODEM_SYSCON<'_>
pub unsafe fn clone_unchecked(&self) -> MODEM_SYSCON<'_>
Unsafely clone this peripheral reference.
Safety
You must ensure that you’re only using one instance of this type at a time.
pub fn reborrow(&mut self) -> MODEM_SYSCON<'_>
pub fn reborrow(&mut self) -> MODEM_SYSCON<'_>
Creates a new peripheral reference with a shorter lifetime.
Use this method if you would like to keep working with the peripheral after you dropped the driver that consumes this.
impl MODEM_SYSCON<'_>
impl MODEM_SYSCON<'_>
pub const PTR: *const <Periph<RegisterBlock, 1611307008> as Deref>::Target = pac::MODEM_SYSCON::PTR
pub const PTR: *const <Periph<RegisterBlock, 1611307008> as Deref>::Target = pac::MODEM_SYSCON::PTR
Pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub const fn ptr() -> *const <Periph<RegisterBlock, 1611307008> as Deref>::Target
pub const fn ptr() -> *const <Periph<RegisterBlock, 1611307008> as Deref>::Target
Return the pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub const fn regs<'a>() -> &'a <Periph<RegisterBlock, 1611307008> as Deref>::Target
pub const fn regs<'a>() -> &'a <Periph<RegisterBlock, 1611307008> as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub fn register_block(
&self,
) -> &<Periph<RegisterBlock, 1611307008> as Deref>::Target
pub fn register_block( &self, ) -> &<Periph<RegisterBlock, 1611307008> as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.