Struct WIFI
#[non_exhaustive]pub struct WIFI<'a> { /* private fields */ }unstable only.Expand description
WIFI peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
impl WIFI<'_>
impl WIFI<'_>
pub fn reset_wifi_mac(&mut self)
Available on wifi only.
pub fn reset_wifi_mac(&mut self)
wifi only.Reset the Wi-Fi MAC.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
impl WIFI<'_>
impl WIFI<'_>
pub unsafe fn steal() -> WIFI<'_>
pub unsafe fn steal() -> WIFI<'_>
Unsafely create an instance of this peripheral out of thin air.
Safety
You must ensure that you’re only using one instance of this type at a time.
pub unsafe fn clone_unchecked(&self) -> WIFI<'_>
pub unsafe fn clone_unchecked(&self) -> WIFI<'_>
Unsafely clone this peripheral reference.
Safety
You must ensure that you’re only using one instance of this type at a time.